summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoPictureKey.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficecore/KoPictureKey.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoPictureKey.h')
-rw-r--r--lib/kofficecore/KoPictureKey.h46
1 files changed, 23 insertions, 23 deletions
diff --git a/lib/kofficecore/KoPictureKey.h b/lib/kofficecore/KoPictureKey.h
index d336215b..09cf6320 100644
--- a/lib/kofficecore/KoPictureKey.h
+++ b/lib/kofficecore/KoPictureKey.h
@@ -20,35 +20,35 @@
#ifndef __koPictureKey_h__
#define __koPictureKey_h__
-#include <qstring.h>
-#include <qdatetime.h>
+#include <tqstring.h>
+#include <tqdatetime.h>
#include <koffice_export.h>
/**
* \file koPictureKey.h
* \todo correct documentation (for example: sed "s/image/picture/g")
*/
-class QDomElement;
+class TQDomElement;
namespace KoPictureType
{
/**
* QPicture version used by KoPictureClipart
*
* Possible values:
- * \li 3 for Qt 2.1.x and later Qt 2.x
- * \li 4 for Qt 3.0
- * \li 5 for Qt 3.1 and later Qt 3.x
- * \li -1 for current Qt
+ * \li 3 for TQt 2.1.x and later TQt 2.x
+ * \li 4 for TQt 3.0
+ * \li 5 for TQt 3.1 and later TQt 3.x
+ * \li -1 for current TQt
*/
- const int formatVersionQPicture=-1;
+ const int formatVersionTQPicture=-1;
enum Type
{
TypeUnknown = 0, ///< Unknown or not-an-image @see KoPictureBase
- TypeImage, ///< Image, QImage-based @see KoPictureImage
+ TypeImage, ///< Image, TQImage-based @see KoPictureImage
TypeEps, ///< Encapsulated Postscript @see KoPictureEps
- TypeClipart, ///< Clipart, QPicture-based @see KoPictureClipart
+ TypeClipart, ///< Clipart, TQPicture-based @see KoPictureClipart
TypeWmf ///< WMF (Windows Meta File) @see KoPictureWmf
};
}
@@ -61,8 +61,8 @@ namespace KoPictureType
* @short Structure describing a picture on disk
*
* @note We use the *nix epoch (1970-01-01) as a time base because it is a valid date.
* That way we do not depend on a behaviour of the current QDateTime that might change in future versions of Qt
* and we are also nice to non-Qt programs wanting to read KOffice's files.
*
* @note This behaviour is also needed for re-saving KWord files having \<FORMAT id="2"\>. When saving again,
* these files get a \<KEY\> element as child of \<PIXMAPS\> but not one as child of \<FORMAT\> and \<IMAGE\>.
@@ -87,13 +87,13 @@ public:
* to update the file and import it into the application again, without
* the application reusing the old copy from the collection.
*/
- KoPictureKey( const QString &fn, const QDateTime &mod );
+ KoPictureKey( const TQString &fn, const TQDateTime &mod );
/**
* Constructs a key from a filename
* @note The modification date is set to 1970-01-01
*/
- KoPictureKey( const QString &fn );
+ KoPictureKey( const TQString &fn );
/**
* Copy constructor
@@ -119,36 +119,36 @@ public:
/**
* Convert this key into a string representation of it
*/
- QString toString() const;
+ TQString toString() const;
/**
* Save this key in XML (as %KOffice 1.3)
*/
- void saveAttributes( QDomElement &elem ) const;
+ void saveAttributes( TQDomElement &elem ) const;
/**
* Load this key from XML (as %KOffice 1.3)
*/
- void loadAttributes( const QDomElement &elem );
+ void loadAttributes( const TQDomElement &elem );
/**
* First part of the key: the filename
*/
- QString filename() const { return m_filename; }
+ TQString filename() const { return m_filename; }
/**
* Second part of the key: the modification date
*/
- QDateTime lastModified() const { return m_lastModified; }
+ TQDateTime lastModified() const { return m_lastModified; }
/**
* Sets the key according to @p filename, including modification time
*/
- void setKeyFromFile (const QString& filename);
+ void setKeyFromFile (const TQString& filename);
protected:
- QString m_filename;
- QDateTime m_lastModified;
+ TQString m_filename;
+ TQDateTime m_lastModified;
};
#endif /* __koPictureKey_h__ */
@@ -20,35 +20,35 @@
{
/**
- * QPicture version used by KoPictureClipart
+ * TQPicture version used by KoPictureClipart
*
* Possible values:
@@ -61,8 +61,8 @@ namespace KoPictureType
*
* @note We use the *nix epoch (1970-01-01) as a time base because it is a valid date.
- * That way we do not depend on a behaviour of the current QDateTime that might change in future versions of Qt
- * and we are also nice to non-Qt programs wanting to read KOffice's files.
+ * That way we do not depend on a behaviour of the current TQDateTime that might change in future versions of TQt
+ * and we are also nice to non-TQt programs wanting to read KOffice's files.
*
* @note This behaviour is also needed for re-saving KWord files having \<FORMAT id="2"\>. When saving again,